summaryrefslogtreecommitdiff
path: root/src/io_object.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:10:49 +0900
committerMartin Sustrik <sustrik@250bpm.com>2012-02-16 10:10:49 +0900
commit50f225a04422abf64545f5eb36592d8c990b0ae4 (patch)
tree1ad0396c3f32b4e89f80d4abdbf0d9ced6a1e55c /src/io_object.hpp
parente5e9852181947a9c41db9ff3c47e94d66a933161 (diff)
poller_base_t renamed to io_thread_t
Signed-off-by: Martin Sustrik <sustrik@250bpm.com>
Diffstat (limited to 'src/io_object.hpp')
-rw-r--r--src/io_object.hpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/io_object.hpp b/src/io_object.hpp
index 0749ceb..31f9507 100644
--- a/src/io_object.hpp
+++ b/src/io_object.hpp
@@ -25,30 +25,30 @@
#include <stddef.h>
#include "stdint.hpp"
-#include "poller_base.hpp"
+#include "io_thread.hpp"
namespace xs
{
// Simple base class for objects that live in I/O threads.
// It makes communication with the poller object easier and
// makes defining unneeded event handlers unnecessary.
class io_object_t : public i_poll_events
{
public:
- io_object_t (xs::poller_base_t *io_thread_ = NULL);
+ io_object_t (xs::io_thread_t *io_thread_ = NULL);
~io_object_t ();
// When migrating an object from one I/O thread to another, first
// unplug it, then migrate it, then plug it to the new thread.
- void plug (xs::poller_base_t *io_thread_);
+ void plug (xs::io_thread_t *io_thread_);
void unplug ();
protected:
// Methods to access underlying poller object.
handle_t add_fd (fd_t fd_);
void rm_fd (handle_t handle_);
void set_pollin (handle_t handle_);
@@ -65,7 +65,7 @@ namespace xs
private:
- poller_base_t *poller;
+ io_thread_t *io_thread;
io_object_t (const io_object_t&);
const io_object_t &operator = (const io_object_t&);
@@ -25,30 +25,30 @@
{
// Simple base class for objects that live in I/O threads.
- // It makes communication with the poller object easier and
+ // It makes communication with the io_thread object easier and
// makes defining unneeded event handlers unnecessary.
class io_object_t : public i_poll_events
@@ -25,30 +25,30 @@
void unplug ();
protected:
- // Methods to access underlying poller object.
+ // Methods to access underlying io_thread object.
handle_t add_fd (fd_t fd_);
void rm_fd (handle_t handle_);